@@ -34,7 +34,7 @@ from evergreen.stats import TaskStats, TestStats
 from evergreen.task import Task
 from evergreen.task_reliability import TaskReliability
 from evergreen.tst import Tst
-from evergreen.util import evergreen_input_to_output, iterate_by_time_window
+from evergreen.util import evergreen_input_to_output, format_evergreen_date, iterate_by_time_window
 from evergreen.version import Requester, Version
 
 try:
@@ -383,6 +383,24 @@ class EvergreenApi(object):
             self.patches_by_project(project_id, params), before, after, time_attr
         )
 
+    def patches_by_user(
+        self, user_id: str, start_at: Optional[datetime] = None, limit: Optional[int] = None
+    ) -> Iterable[Patch]:
+        """
+        Get an iterable of recent patches by the given user.
+
+        :param user_id: Id of user to query.
+        :param start_at: If specified, query starting at the given date.
+        :param limit: If specified, limit the output per page.
+        """
+        params: Dict[str, Any] = {}
+        if start_at:
+            params["start_at"] = start_at
+        if limit:
+            params["limit"] = limit
+        url = self._create_url(f"/users/{user_id}/patches")
+        return (Patch(patch, self) for patch in self._lazy_paginate(url, params))
+
     def commit_queue_for_project(self, project_id: str) -> CommitQueue:
         """
         Get the current commit queue for the specified project.
@@ -424,8 +442,8 @@ class EvergreenApi(object):
         :return: Patch queried for.
         """
         params: Dict[str, Any] = {
-            "after_date": after_date,
-            "before_date": before_date,
+            "after_date": format_evergreen_date(after_date),
+            "before_date": format_evergreen_date(before_date),
         }
         if group_num_days:
             params["group_num_days"] = group_num_days
@@ -490,13 +508,13 @@ class EvergreenApi(object):
         :return: Patch queried for.
         """
         params: Dict[str, Any] = {
-            "after_date": after_date,
-            "before_date": before_date,
+            "after_date": format_evergreen_date(after_date),
+            "before_date": format_evergreen_date(before_date),
         }
         if group_num_days:
             params["group_num_days"] = group_num_days
         if requesters:
-            params["requesters"] = requesters
+            params["requesters"] = requesters.stats_value()
         if tasks:
             params["tasks"] = tasks
         if variants:
@@ -507,7 +525,7 @@ class EvergreenApi(object):
             params["group_by"] = group_by
         if sort:
             params["sort"] = sort
-        url = self._create_url("/projects/{project_id}/task_stats".format(project_id=project_id))
+        url = self._create_url(f"/projects/{project_id}/task_stats")
         task_stats_list = self._paginate(url, params)
         return [TaskStats(task_stat, self) for task_stat in task_stats_list]  # type: ignore[arg-type]
 
@@ -541,13 +559,13 @@ class EvergreenApi(object):
         """
         params: Dict[str, Any] = {}
         if after_date:
-            params["after_date"] = after_date
+            params["after_date"] = format_evergreen_date(after_date)
         if before_date:
-            params["before_date"] = before_date
+            params["before_date"] = format_evergreen_date(before_date)
         if group_num_days:
             params["group_num_days"] = group_num_days
         if requesters:
-            params["requesters"] = requesters
+            params["requesters"] = requesters.stats_value()
         if tasks:
             params["tasks"] = tasks
         if variants:
@@ -558,9 +576,8 @@ class EvergreenApi(object):
             params["group_by"] = group_by
         if sort:
             params["sort"] = sort
-        url = self._create_url(
-            "/projects/{project_id}/task_reliability".format(project_id=project_id)
-        )
+
+        url = self._create_url(f"/projects/{project_id}/task_reliability")
         task_reliability_scores = self._paginate(url, params)
         return [
             TaskReliability(task_reliability, self) for task_reliability in task_reliability_scores  # type: ignore[arg-type]
